﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using Telerik.Windows.Controls.Diagrams;
using Telerik.Windows.Controls.Diagrams.Extensions;
using Telerik.Windows.Controls.Diagrams.Extensions.ViewModels;
using Telerik.Windows.Diagrams.Core;

namespace CustomSettingsPane
{
	/// <summary>
	/// Interaction logic for MainWindow.xaml
	/// </summary>
	public partial class MainWindow : Window
	{
		private FileManager fileManager;

		static MainWindow()
		{
			var saveBinding = new CommandBinding(DiagramCommands.Save, ExecuteSave, CanExecutedSave);
			var openBinding = new CommandBinding(DiagramCommands.Open, ExecuteOpen);

			CommandManager.RegisterClassCommandBinding(typeof(MainWindow), saveBinding);
			CommandManager.RegisterClassCommandBinding(typeof(MainWindow), openBinding);
		}

		private static void CanExecutedSave(object sender, CanExecuteRoutedEventArgs e)
		{
			var owner = sender as MainWindow;
			e.CanExecute = owner != null && owner.diagram != null && owner.diagram.Items.Count > 0;
		}

		private static void ExecuteSave(object sender, ExecutedRoutedEventArgs e)
		{
			var owner = sender as MainWindow;
			if (owner != null)
				owner.fileManager.SaveToFile();
		}

		private static void ExecuteOpen(object sender, ExecutedRoutedEventArgs e)
		{
			var owner = sender as MainWindow;
			if (owner != null)
			{
				owner.fileManager.LoadFromFile();
			}
		}

		public MainWindow()
		{

			InitializeComponent();
			this.toolbox.ItemsSource = new HierarchicalGalleryItemsCollection();
			this.fileManager = new FileManager(this.diagram);
			this.diagram.GraphSource = new MyGraphSource();
			SerializationService.Default.ItemSerializing += Default_ItemSerializing;

		}

		void Default_ItemSerializing(object sender, SerializationEventArgs<IDiagramItem> e)
		{
			
		}

		private void diagram_PreviewAdditionalContentActivated(object sender, AdditionalContentActivatedEventArgs e)
		{
			if ((e.ContextItems.FirstOrDefault().Content as MyNode).IsSecondType)
			{
				this.settingsPane.SettingsPaneViewStyle = this.Resources["SettingsPaneViewStyle2"] as Style;
			}
			else
			{
				this.settingsPane.SettingsPaneViewStyle = this.Resources["SettingsPaneViewStyle"] as Style;
			}
		}
	}
}
